# Chembl

This module is used to query the [Chembl](https://ebi.ac.uk/chembl) database.

Currently the query-APIs available are:

| Module | Description |
|--------|-------------|
| [`activity`](./chembl/activity.md) | Queries for checmical bioactivity for a provided protein-target. |
